@@ -3,12 +3,19 @@ import errno
 import os
 
 from enigma import eEnv
-from re import compile, split
+from datetime import datetime
+from re import compile
 from stat import S_IMODE
 from sys import _getframe as getframe
 from unicodedata import normalize
+from traceback import print_exc
+from xml.etree.ElementTree import Element, fromstring, parse
+
+
+from os.path import exists as pathExists, isdir as pathIsdir, isfile as pathIsfile, join as pathJoin
+
+from os import listdir
 
-pathExists = os.path.exists
 
 SCOPE_HOME = 0  # DEBUG: Not currently used in Enigma2.
 SCOPE_LANGUAGE = 1
@@ -80,9 +87,10 @@ def addInList(*paths):
 	return [path for path in paths if os.path.isdir(path)]
 
 
-skinResolveList = []
-lcdskinResolveList = []
-fontsResolveList = []
+class ResolveList:
+	skin = []
+	lcdskin = []
+	fonts = []
 
 
 def resolveFilename(scope, base="", path_prefix=None):
@@ -139,30 +147,31 @@ def resolveFilename(scope, base="", path_prefix=None):
 					relative = "%s%s%s" % (pluginCode[0], os.sep, pluginCode[1])
 					path = os.path.join(plugins, relative)
 	elif scope == SCOPE_GUISKIN:
-		global skinResolveList
-		if not skinResolveList:
+		if not ResolveList.skin:
 			# This import must be here as this module finds the config file as part of the config initialisation.
 			from Components.config import config
-			skin = os.path.dirname(config.skin.primary_skin.value)
-			skinResolveList = addInList(
-				os.path.join(scopeConfig, skin),
+			skin_primary = os.path.dirname(config.skin.primary_skin.value)
+			skin_default = os.path.dirname(config.skin.primary_skin.default)
+			ResolveList.skin = addInList(
+				os.path.join(scopeConfig, skin_primary),
+				os.path.join(scopeConfig, skin_default),
 				os.path.join(scopeConfig, "skin_common"),
 				scopeConfig,
-				os.path.join(scopeGUISkin, skin),
+				os.path.join(scopeGUISkin, skin_primary),
+				os.path.join(scopeGUISkin, skin_default),
 				os.path.join(scopeGUISkin, "skin_default"),
 				scopeGUISkin
 			)
-		path = itemExists(skinResolveList, base)
+		path = itemExists(ResolveList.skin, base)
 	elif scope == SCOPE_LCDSKIN:
-		global lcdskinResolveList
-		if not lcdskinResolveList:
+		if not ResolveList.lcdskin:
 			# This import must be here as this module finds the config file as part of the config initialisation.
 			from Components.config import config
 			if hasattr(config.skin, "display_skin"):
 				skin = os.path.dirname(config.skin.display_skin.value)
 			else:
 				skin = ""
-			lcdskinResolveList = addInList(
+			ResolveList.lcdskin = addInList(
 				os.path.join(scopeConfig, "display", skin),
 				os.path.join(scopeConfig, "display", "skin_common"),
 				scopeConfig,
@@ -170,43 +179,47 @@ def resolveFilename(scope, base="", path_prefix=None):
 				os.path.join(scopeLCDSkin, "skin_default"),
 				scopeLCDSkin
 			)
-		path = itemExists(lcdskinResolveList, base)
+		path = itemExists(ResolveList.lcdskin, base)
 	elif scope == SCOPE_FONTS:
-		global fontsResolveList
-		if not fontsResolveList:
+		if not ResolveList.fonts:
 			# This import must be here as this module finds the config file as part of the config initialisation.
 			from Components.config import config
-			skin = os.path.dirname(config.skin.primary_skin.value)
+			skin_primary = os.path.dirname(config.skin.primary_skin.value)
+			skin_default = os.path.dirname(config.skin.primary_skin.default)
 			display = os.path.dirname(config.skin.display_skin.value) if hasattr(config.skin, "display_skin") else None
-			fontsResolveList = addInList(
+			ResolveList.fonts = addInList(
 				os.path.join(scopeConfig, "fonts"),
-				os.path.join(scopeConfig, skin, "fonts"),
-				os.path.join(scopeConfig, skin)
+				os.path.join(scopeConfig, skin_primary, "fonts"),
+				os.path.join(scopeConfig, skin_primary),
+				os.path.join(scopeConfig, skin_default, "fonts"),
+				os.path.join(scopeConfig, skin_default)
 			)
 			if display:
-				fontsResolveList += addInList(
+				ResolveList.fonts += addInList(
 					os.path.join(scopeConfig, "display", display, "fonts"),
 					os.path.join(scopeConfig, "display", display)
 				)
-			fontsResolveList += addInList(
+			ResolveList.fonts += addInList(
 				os.path.join(scopeConfig, "skin_common"),
 				scopeConfig,
-				os.path.join(scopeGUISkin, skin, "fonts"),
-				os.path.join(scopeGUISkin, skin),
+				os.path.join(scopeGUISkin, skin_primary, "fonts"),
+				os.path.join(scopeGUISkin, skin_primary),
+				os.path.join(scopeGUISkin, skin_default, "fonts"),
+				os.path.join(scopeGUISkin, skin_default),
 				os.path.join(scopeGUISkin, "skin_default", "fonts"),
 				os.path.join(scopeGUISkin, "skin_default")
 			)
 			if display:
-				fontsResolveList += addInList(
+				ResolveList.fonts += addInList(
 					os.path.join(scopeLCDSkin, display, "fonts"),
 					os.path.join(scopeLCDSkin, display)
 				)
-			fontsResolveList += addInList(
+			ResolveList.fonts += addInList(
 				os.path.join(scopeLCDSkin, "skin_default", "fonts"),
 				os.path.join(scopeLCDSkin, "skin_default"),
 				scopeFonts
 			)
-		path = itemExists(fontsResolveList, base)
+		path = itemExists(ResolveList.fonts, base)
 	elif scope == SCOPE_PLUGIN:
 		file = os.path.join(scopePlugins, base)
 		if pathExists(file):
@@ -335,20 +348,33 @@ def fileHas(f, content, mode="r"):
 	return result
 
 
+def fileDate(f):
+	if fileExists(f):
+		return datetime.fromtimestamp(os.stat(f).st_mtime).strftime("%Y-%m-%d")
+	return("1970-01-01")
+
+
+def fileReadXML(filename, default=None, *args, **kwargs):
+	dom = None
+	try:
+		with open(filename, "r", encoding="utf-8") as fd:
+			dom = parse(fd).getroot()
+	except:
+		print("[fileReadXML] failed to read", filename)
+		print_exc()
+	if dom is None and default:
+		if isinstance(default, str):
+			dom = fromstring(default)
+		elif isinstance(default, Element):
+			dom = default
+	return dom
+
+
 def getRecordingFilename(basename, dirname=None):
-	# Filter out non-allowed characters.
-	non_allowed_characters = "/.\\:*?<>|\""
-	basename = basename.replace("\xc2\x86", "").replace("\xc2\x87", "")
-	filename = ""
-	for c in basename:
-		if c in non_allowed_characters or ord(c) < 32:
-			c = "_"
-		filename += c
-	# Max filename length for ext4 is 255 (minus 8 characters for .ts.meta)
-	# but must not truncate in the middle of a multi-byte utf8 character!
-	# So convert the truncation to unicode and back, ignoring errors, the
-	# result will be valid utf8 and so xml parsing will be OK.
-	filename = filename[:247]
+	# The "replaces" remove dvb emphasis chars.
+	# Also, "." is replaced with "_" which respects the original code.
+	# Max filename length for ext4 is 255 bytes (minus 8 bytes for ".ts.meta", minus 4 bytes for "_%03d")
+	filename = sanitizeFilename(basename.replace("\xc2\x86", "").replace("\xc2\x87", "").replace(".", "_"), maxlen=243)
 	if dirname is not None:
 		if not dirname.startswith("/"):
 			dirname = os.path.join(defaultRecordingLocation(), dirname)
@@ -360,7 +386,7 @@ def getRecordingFilename(basename, dirname=None):
 	while True:
 		if not os.path.isfile(path + ".ts"):
 			return path
-		path += "_%03d" % i
+		path = "%s_%03d" % (filename, i)
 		i += 1
 
 # This is clearly a hack:
@@ -544,49 +570,52 @@ def mediafilesInUse(session):
 def shellquote(s):
 	return "'%s'" % s.replace("'", "'\\''")
 
+def isPluginInstalled(pluginname, pluginfile="plugin", pluginType=None):
+	path = resolveFilename(SCOPE_PLUGINS)
+	pluginfolders = [name for name in listdir(path) if pathIsdir(pathJoin(path, name)) and name not in ["__pycache__"]]
+	if pluginType is None or pluginType in pluginfolders:
+		plugintypes = pluginType and [pluginType] or pluginfolders
+		for fileext in [".pyc", ".py"]:
+			for plugintype in plugintypes:
+				if pathIsfile(pathJoin(path, plugintype, pluginname, pluginfile + fileext)):
+					return True
+	return False
 
-def sanitizeFilename(filename):
+
+def sanitizeFilename(filename, maxlen=255):  # 255 is max length in bytes in ext4 (and most other file systems)
 	"""Return a fairly safe version of the filename.
 
 	We don't limit ourselves to ascii, because we want to keep municipality
 	names, etc, but we do want to get rid of anything potentially harmful,
-	and make sure we do not exceed Windows filename length limits.
+	and make sure we do not exceed filename length limits.
 	Hence a less safe blacklist, rather than a whitelist.
 	"""
-	blacklist = ["\\", "/", ":", "*", "?", "\"", "<", ">", "|", "\0", "(", ")", " "]
+	blacklist = ["\\", "/", ":", "*", "?", "\"", "<", ">", "|", "\0"]
 	reserved = [
 		"CON", "PRN", "AUX", "NUL", "COM1", "COM2", "COM3", "COM4", "COM5",
 		"COM6", "COM7", "COM8", "COM9", "LPT1", "LPT2", "LPT3", "LPT4", "LPT5",
 		"LPT6", "LPT7", "LPT8", "LPT9",
 	]  # Reserved words on Windows
-	filename = "".join(c for c in filename if c not in blacklist)
-	# Remove all charcters below code point 32
-	filename = "".join(c for c in filename if 31 < ord(c))
-	filename = normalize("NFKD", filename)
+	# Remove any blacklisted chars. Remove all charcters below code point 32. Normalize. Strip.
+	filename = normalize("NFKD", "".join(c for c in filename if c not in blacklist and ord(c) > 31)).strip()
+	if all([x == "." for x in filename]) or filename in reserved:  # if filename is a string of dots
+		filename = "__" + filename
+	# Most Unix file systems typically allow filenames of up to 255 bytes.
+	# However, the actual number of characters allowed can vary due to the
+	# representation of Unicode characters. Therefore length checks must
+	# be done in bytes, not unicode.
+	#
+	# Also we cannot leave the byte truncate in the middle of a multi-byte
+	# utf8 character! So, convert to bytes, truncate then get back to unicode,
+	# ignoring errors along the way, the result will be valid unicode.
+	# Prioritise maintaining the complete extension if possible.
+	# Any truncation of "root" or "ext" will be done at the end of the string
+	root, ext = os.path.splitext(filename.encode(encoding='utf-8', errors='ignore'))
+	if len(ext) > maxlen - (1 if root else 0):  # leave at least one char for root if root
+		ext = ext[:maxlen - (1 if root else 0)]
+	# convert back to unicode, ignoring any incomplete utf8 multibyte chars
+	filename = root[:maxlen - len(ext)].decode(encoding='utf-8', errors='ignore') + ext.decode(encoding='utf-8', errors='ignore')
 	filename = filename.rstrip(". ")  # Windows does not allow these at end
-	filename = filename.strip()
-	if all([x == "." for x in filename]):
-		filename = "__" + filename
-	if filename in reserved:
-		filename = "__" + filename
 	if len(filename) == 0:
 		filename = "__"
-	if len(filename) > 255:
-		parts = split(r"/|\\", filename)[-1].split(".")
-		if len(parts) > 1:
-			ext = "." + parts.pop()
-			filename = filename[:-len(ext)]
-		else:
-			ext = ""
-		if filename == "":
-			filename = "__"
-		if len(ext) > 254:
-			ext = ext[254:]
-		maxl = 255 - len(ext)
-		filename = filename[:maxl]
-		filename = filename + ext
-		# Re-check last character (if there was no extension)
-		filename = filename.rstrip(". ")
-		if len(filename) == 0:
-			filename = "__"
 	return filename
